@@ -1,5 +1,5 @@
 package Plack::Middleware::DebugLogging;
-$Plack::Middleware::DebugLogging::VERSION = '0.001002';
+$Plack::Middleware::DebugLogging::VERSION = '0.001003';
 # ABSTRACT: Catalyst style console debugging for plack apps
 
 use strict;
@@ -247,7 +247,7 @@ Plack::Middleware::DebugLogging - Catalyst style console debugging for plack app
 
 =head1 VERSION
 
-version 0.001002
+version 0.001003
 
 =head1 SYNOPSIS
 
@@ -260,28 +260,43 @@ version 0.001002
     $app;
   }
 
-curl -XPOST http://0:5000/api/1/2? -d'foo=bar&foo=baz'
+curl -XPOST http://0:5000/api/1/2?query=param -d'foo=bar&foo=baz&zap=555'
 
   "POST" request for "/api/1/2" from "127.0.0.1"
   Request Headers:
-  .-----------------+---------------------------------------------------------------.
-  | Header Name     | Value                                                         |
-  +-----------------+---------------------------------------------------------------+
-  | Accept          | */*                                                           |
-  | Host            | 0:5000                                                        |
-  | User-Agent      | curl/7.22.0 (i686-pc-linux-gnu) libcurl/7.22.0 OpenSSL/1.0.1- |
-  |                 |  zlib/1.2.3.4 libidn/1.23 librtmp/2.3                         |
-  | Content-Length  | 15                                                            |
-  | Content-Type    | application/x-www-form-urlencoded                             |
-  '-----------------+---------------------------------------------------------------'
+  .-----------------+------------------------------------------------------.
+  | Header Name     | Value                                                |
+  +-----------------+------------------------------------------------------+
+  | Accept          | */*                                                  |
+  | Host            | 0:5000                                               |
+  | User-Agent      | curl/7.22.0 (i686-pc-linux-gnu) libcurl/7.22.0 Open- |
+  |                 | SSL/1.0.1 zlib/1.2.3.4 libidn/1.23 librtmp/2.3       |
+  | Content-Length  | 23                                                   |
+  | Content-Type    | application/x-www-form-urlencoded                    |
+  '-----------------+------------------------------------------------------'
+
+  Query Parameters are:
+  .-------------------------------------+--------------------------------------.
+  | Parameter                           | Value                                |
+  +-------------------------------------+--------------------------------------+
+  | query                               | param                                |
+  '-------------------------------------+--------------------------------------'
+
+  Body Parameters are:
+  .-------------------------------------+--------------------------------------.
+  | Parameter                           | Value                                |
+  +-------------------------------------+--------------------------------------+
+  | foo                                 | bar, baz                             |
+  | zap                                 | 555                                  |
+  '-------------------------------------+--------------------------------------'
 
   Response Code: 404; Content-Type: text/plain; Content-Length: unknown
   Response Headers:
-  .-----------------+---------------------------------------------------------------.
-  | Header Name     | Value                                                         |
-  +-----------------+---------------------------------------------------------------+
-  | Content-Type    | text/plain                                                    |
-  '-----------------+---------------------------------------------------------------'
+  .-----------------+------------------------------------------------------.
+  | Header Name     | Value                                                |
+  +-----------------+------------------------------------------------------+
+  | Content-Type    | text/plain                                           |
+  '-----------------+------------------------------------------------------'
 
 =head1 DESCRIPTION
 
